#ifndef NT2_INCLUDE_CONSTANTS_RADINDEGR_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_RADINDEGR_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/radindegr.hpp>

#endif
